CarouselIndicator class

Inheritance

Constructors

CarouselIndicator({Key? key, required int itemCount, required int currentIndex, Color activeColor = Colors.black, Color inactiveColor = Colors.grey, double activeWidth = 20.0, double activeHeight = 5.0, double inactiveWidth = 10.0, double inactiveHeight = 5.0, double spacing = 8.0, Color activeBorderColor = Colors.transparent, double activeBorderWidth = 0.0, Color inactiveBorderColor = Colors.transparent, double inactiveBorderWidth = 0.0})
const

Properties

activeBorderColor → Color
final
activeBorderWidth → double
final
activeColor → Color
final
activeHeight → double
final
activeWidth → double
final
currentIndex → int
final
hashCode → int
The hash code for this object.
no setterinherited
inactiveBorderColor → Color
final
inactiveBorderWidth → double
final
inactiveColor → Color
final
inactiveHeight → double
final
inactiveWidth → double
final
itemCount → int
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited